@@ -244,12 +244,6 @@ private slots:
      */
     void activate();
 
-    /**
-     * Is invoked if the signal urlAboutToBeChanged() from the DolphinView
-     * is emitted. Tries to save the view-state.
-     */
-    void slotViewUrlAboutToBeChanged(const QUrl& url);
-
     /**
      * Is invoked if the signal urlAboutToBeChanged() from the URL navigator
      * is emitted. Tries to save the view-state.
@@ -278,8 +272,6 @@ private slots:
      */
     void saveUrlCompletionMode(KCompletion::CompletionMode completion);
 
-    void slotHistoryChanged();
-
     void slotReturnPressed();
 
     /**
@@ -313,6 +305,12 @@ private:
      */
     void saveViewState();
 
+    /**
+     * Restores the state of the current view iff the URL navigator contains a
+     * non-empty location state.
+     */
+    void tryRestoreViewState();
+
 private:
     QVBoxLayout* m_topLayout;
     KUrlNavigator* m_urlNavigator;
